@@ -24,6 +24,9 @@
 #include "box_data.h"
 #include "../utility_widgets/db_adddel/db_adddel_withbuttons.h"
 
+namespace Glom
+{
+
 class Box_Data_List : public Box_Data
 {
 public: 
@@ -68,6 +71,8 @@ public:
 
 protected:
   virtual void create_layout(); //override
+  virtual Document_Glom::type_mapLayoutGroupSequence create_layout_get_layout(); //overriden in Box_Data_List_Related.
+  void create_layout_add_group(const sharedptr<LayoutGroup>& layout_group);
   virtual bool fill_from_database(); //override.
   virtual void enable_buttons();
 
@@ -100,4 +105,6 @@ protected:
   type_signal_user_requested_details m_signal_user_requested_details;
 };
 
+} //namespace Glom
+
 #endif
