@@ -23,10 +23,14 @@
 #include "dialog_identify_original.h"
 #include "dialog_copy_translation.h"
 #include <bakery/App/App_Gtk.h> //For util_bold_message().
+#include "glom/libglom/utils.h"
 
 //#include <libgnome/gnome-i18n.h>
 #include <glibmm/i18n.h>
 
+namespace Glom
+{
+
 Window_Translations::Window_Translations(BaseObjectType* cobject, const Glib::RefPtr<Gnome::Glade::Xml>& refGlade)
 : Gtk::Window(cobject),
   m_treeview(0),
@@ -117,7 +121,7 @@ void Window_Translations::on_button_identify()
       add_view(dialog);
       dialog->load_from_document(); //Doesn't seem to happen otherwise.
       dialog->set_transient_for(*this);
-      const int response = dialog->run();
+      const int response = Glom::Utils::dialog_run_with_help(dialog, "dialog_translation_identify_original");
       dialog->hide();
 
       if(response == Gtk::RESPONSE_OK)
@@ -244,15 +248,36 @@ void Window_Translations::load_from_document()
     Document_Glom::type_listReports listReports = document->get_report_names(table_name);
     for(Document_Glom::type_listReports::iterator iter = listReports.begin(); iter != listReports.end(); ++iter)
     {
-      sharedptr<Report> report = document->get_report(table_name, *iter);
+      const Glib::ustring report_name = *iter;
+      sharedptr<Report> report = document->get_report(table_name, report_name);
       if(report)
       {
+        //Translatable report title:
         Gtk::TreeModel::iterator iterTree = m_model->append();
         Gtk::TreeModel::Row row = *iterTree;
 
         row[m_columns.m_col_item] = report;
         row[m_columns.m_col_translation] = report->get_title(m_translation_locale);
         row[m_columns.m_col_parent_table] = table_name;
+
+        //Translatable report items:
+        Document_Glom::type_list_translatables list_layout_items = document->get_translatable_report_items(table_name, report_name);
+        for(Document_Glom::type_list_translatables::iterator iter = list_layout_items.begin(); iter != list_layout_items.end(); ++iter)
+        {
+          sharedptr<TranslatableItem> item = *iter;
+          if(item)
+          {
+            if(!(item->get_title_original().empty()))
+            {
+              Gtk::TreeModel::iterator iterTree = m_model->append();
+              Gtk::TreeModel::Row row = *iterTree;
+
+              row[m_columns.m_col_item] = item;
+              row[m_columns.m_col_translation] = item->get_title(m_translation_locale);
+              row[m_columns.m_col_parent_table] = table_name;
+            }
+          }
+        }
       }
     }
 
@@ -324,7 +349,7 @@ void Window_Translations::on_button_copy_translation()
     if(dialog)
     {
       dialog->set_transient_for(*this);
-      const int response = dialog->run();
+      const int response = Glom::Utils::dialog_run_with_help(dialog, "dialog_translation_copy");
       dialog->hide();
 
       if(response == Gtk::RESPONSE_OK)
@@ -372,3 +397,5 @@ void Window_Translations::on_treeview_edited(const Glib::ustring& /* path */, co
   m_treeview_modified = true;
 }
 
+
+} //namespace Glom
